@@ -1,24 +1,31 @@
 package Boxer::CLI;
 
-use 5.01;
-use strictures 1;
-use utf8;
-
-use App::Cmd::Setup -app;
-
-use Role::Commons -all;
-
-our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = 'v1.1.0';
-
-1;
-
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
 Boxer::CLI - boxer command line utils
 
+=cut
+
+use v5.14;
+use utf8;
+use strictures 2;
+use version;
+use Role::Commons -all;
+
+use App::Cmd::Setup -app;
+
+use namespace::clean;
+
+=head1 VERSION
+
+Version v1.1.7
+
+=cut
+
+our $VERSION = version->declare("v1.1.7");
+
 =head1 SYNOPSIS
 
  use Boxer::CLI;
@@ -34,11 +41,15 @@ L<boxer>, L<Boxer>.
 
 =head1 AUTHOR
 
-Jonas Smedegaard E<lt>dr@jones.dkE<gt>.
+Jonas Smedegaard C<< <dr@jones.dk> >>.
+
+=cut
+
+our $AUTHORITY = 'cpan:JONASS';
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2015 by Jonas Smedegaard.
+Copyright © 2013-2016 Jonas Smedegaard
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -48,3 +59,7 @@ the same terms as the Perl 5 programming language system itself.
 THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
+
+1;
