@@ -1,17 +1,27 @@
 package Boxer::CLI::Command::Aliases;
 
-use 5.010;
-use strictures 1;
+=encoding UTF-8
+
+=cut
+
+use v5.14;
 use utf8;
-use match::simple qw(match);
-
-use Boxer::CLI -command;
-use namespace::clean;
-
+use strictures 2;
+use version;
 use Role::Commons -all;
 
-our $AUTHORITY = 'cpan:JONASS';
-our $VERSION = 'v1.1.4';
+use match::simple qw(match);
+use Boxer::CLI -command;
+
+use namespace::clean;
+
+=head1 VERSION
+
+Version v1.1.7
+
+=cut
+
+our $VERSION = version->declare("v1.1.7");
 
 use constant {
 	abstract   => q[show aliases for boxer commands],
@@ -59,4 +69,27 @@ sub execute
 	}
 }
 
+=head1 AUTHOR
+
+Jonas Smedegaard C<< <dr@jones.dk> >>.
+
+=cut
+
+our $AUTHORITY = 'cpan:JONASS';
+
+=head1 COPYRIGHT AND LICENCE
+
+Copyright © 2013-2016 Jonas Smedegaard
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
+
 1;
