@@ -1,24 +1,37 @@
 package Boxer::Task::Classify;
 
-use 5.010;
-use strictures 1;
+=encoding UTF-8
+
+=cut
+
+use v5.14;
 use utf8;
+use strictures 2;
+use version;
+use Role::Commons -all;
 use autodie qw(:all);
 use IPC::System::Simple;
 
-use Moo;
-use Boxer::Types qw( DataDir ClassDir NodeDir Suite );
-use Types::Standard qw( Maybe Str Undef );
-extends 'Boxer::Task';
-
 use File::BaseDir qw(data_dirs);
 use Capture::Tiny qw(capture_stdout);
 use YAML::XS;
+use Boxer::World::Reclass;
+use Boxer::Part::Reclass;
 
-use Role::Commons -all;
+use Moo;
+use Types::Standard qw( Maybe Str Undef );
+use Boxer::Types qw( DataDir ClassDir NodeDir Suite );
+extends 'Boxer::Task';
 
-our $AUTHORITY = 'cpan:JONASS';
-our $VERSION = 'v1.1.4';
+use namespace::clean;
+
+=head1 VERSION
+
+Version v1.1.7
+
+=cut
+
+our $VERSION = version->declare("v1.1.7");
 
 # permit callers to sloppily pass undefined values
 sub BUILDARGS
@@ -30,10 +43,10 @@ sub BUILDARGS
 
 has datadir => (
 	is       => 'lazy',
-	isa      => Maybe[DataDir],
+	isa      => Maybe [DataDir],
 	coerce   => 1,
 	required => 1,
-	default  => sub { undef },
+	default  => sub {undef},
 );
 
 has suite => (
@@ -49,7 +62,11 @@ has classdir => (
 	isa      => ClassDir,
 	coerce   => 1,
 	required => 1,
-	default  => sub { $_[0]->datadir ? $_[0]->datadir->child('classes') : scalar( data_dirs( 'boxer', $_[0]->suite, 'classes' ) ) },
+	default  => sub {
+		$_[0]->datadir
+			? $_[0]->datadir->child('classes')
+			: scalar( data_dirs( 'boxer', $_[0]->suite, 'classes' ) );
+	},
 );
 
 has nodedir => (
@@ -64,7 +81,7 @@ sub run
 {
 	my $self = shift;
 
-	Load(
+	my $data = Load(
 		scalar(
 			capture_stdout {
 				system(
@@ -80,6 +97,43 @@ sub run
 			}
 		)
 	);
+
+	my @parts;
+	for ( keys %{ $data->{nodes} } ) {
+		push @parts,
+			Boxer::Part::Reclass->new(
+			id    => $_,
+			epoch => $self->suite,
+			%{ $data->{nodes}{$_}{parameters} }
+			);
+	}
+
+	return Boxer::World::Reclass->new(
+		parts => \@parts,
+	);
 }
 
+=head1 AUTHOR
+
+Jonas Smedegaard C<< <dr@jones.dk> >>.
+
+=cut
+
+our $AUTHORITY = 'cpan:JONASS';
+
+=head1 COPYRIGHT AND LICENCE
+
+Copyright © 2013-2016 Jonas Smedegaard
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+=cut
+
 1;
